package ukol;

import java.awt.BorderLayout;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import javax.swing.JComboBox;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import ukol.dotazy.LibovolnySQL;
import ukol.dotazy.NovyAutor;
import ukol.dotazy.SQLAdapter;
import ukol.dotazy.SeznamKnih;
import ukol.dotazy.SeznamVydavatelu;
import ukol.dotazy.UpdateAuthor;
import ukol.dotazy.VsichniAutori;
import ukol.dotazy.VsichniVydavatele;

/**
 * Komponenta uživatelského rozhraní umožňující zadat dotaz do databáze a zobrazující
 * výsledek tohoto dotazu.
 */
public class DisplayQueryResults extends JPanel {

    /**
     * Výběr SQL dotazu
     */
    private JComboBox queryList;
    SQLAdapter[] dotazy;

    /**
     * Vytvoří novou instanci třídy DisplayQueryResults.
     *
     * @param tableModel
     *            model obsahující výsledky dotazu.
     */
    public DisplayQueryResults(ResultSetTableModel tableModel) throws SQLException {
        setLayout(new BorderLayout());

        dotazy = new SQLAdapter[7];
        dotazy[0] = new VsichniAutori(tableModel.getConnection());
        dotazy[1] = new VsichniVydavatele(tableModel.getConnection());
        dotazy[2] = new SeznamKnih(tableModel.getConnection());
        dotazy[3] = new SeznamVydavatelu(tableModel.getConnection());
        dotazy[4] = new LibovolnySQL(tableModel.getConnection());
        dotazy[5] = new NovyAutor(tableModel.getConnection());
        dotazy[6] = new UpdateAuthor(tableModel.getConnection());

        queryList = new JComboBox(dotazy);

        DisplayQueryResultsController controller =
                new DisplayQueryResultsController(tableModel, this);
        queryList.addActionListener(controller);
        tableModel.setResult(((SQLAdapter) queryList.getSelectedItem()).getResult());


        // tabulka zobrazující výsledek dotazu
        JTable resultTable = new JTable(tableModel);

        add(queryList, BorderLayout.NORTH);
        add(new JScrollPane(resultTable), BorderLayout.CENTER);
    }

    /**
     * Vrátí užvatelem zadaný dotaz.
     *
     * @return vysledek dotazu
     */
    public ResultSet getResult() throws SQLException {
        return ((SQLAdapter) queryList.getSelectedItem()).getResult();
    }
}
